==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/YamlFile.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Represents a YAML file.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.458Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.YamlFile")
public class YamlFile extends io.github.cdklabs.projen.ObjectFile {

    protected YamlFile(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected YamlFile(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param filePath This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public YamlFile(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull java.lang.String filePath, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.YamlFileOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(filePath, "filePath is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Implemented by derived classes and returns the contents of the file to emit.
     * <p>
     * @param resolver This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    protected @org.jetbrains.annotations.Nullable java.lang.String synthesizeContent(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IResolver resolver) {
        return software.amazon.jsii.Kernel.call(this, "synthesizeContent", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { java.util.Objects.requireNonNull(resolver, "resolver is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.YamlFile}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.YamlFile> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         * @param filePath This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project, final java.lang.String filePath) {
            return new Builder(project, filePath);
        }

        private final io.github.cdklabs.projen.Project project;
        private final java.lang.String filePath;
        private final io.github.cdklabs.projen.YamlFileOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project, final java.lang.String filePath) {
            this.project = project;
            this.filePath = filePath;
            this.options = new io.github.cdklabs.projen.YamlFileOptions.Builder();
        }

        /**
         * (experimental) Indicates whether this file should be committed to git or ignored.
         * <p>
         * By
         * default, all generated files are committed and anti-tamper is used to
         * protect against manual modifications.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param committed Indicates whether this file should be committed to git or ignored. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder committed(final java.lang.Boolean committed) {
            this.options.committed(committed);
            return this;
        }

        /**
         * (experimental) Update the project's .gitignore file.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param editGitignore Update the project's .gitignore file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder editGitignore(final java.lang.Boolean editGitignore) {
            this.options.editGitignore(editGitignore);
            return this;
        }

        /**
         * (experimental) Whether the generated file should be marked as executable.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param executable Whether the generated file should be marked as executable. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder executable(final java.lang.Boolean executable) {
            this.options.executable(executable);
            return this;
        }

        /**
         * (experimental) Whether the generated file should be readonly.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param readonly Whether the generated file should be readonly. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder readonly(final java.lang.Boolean readonly) {
            this.options.readonly(readonly);
            return this;
        }

        /**
         * (experimental) Adds the projen marker to the file.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param marker Adds the projen marker to the file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder marker(final java.lang.Boolean marker) {
            this.options.marker(marker);
            return this;
        }

        /**
         * (experimental) The object that will be serialized.
         * <p>
         * You can modify the object's contents
         * before synthesis.
         * <p>
         * Default: {} an empty object (use `file.obj` to mutate).
         * <p>
         * @return {@code this}
         * @param obj The object that will be serialized. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder obj(final java.lang.Object obj) {
            this.options.obj(obj);
            return this;
        }

        /**
         * (experimental) Omits empty objects and arrays.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param omitEmpty Omits empty objects and arrays. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder omitEmpty(final java.lang.Boolean omitEmpty) {
            this.options.omitEmpty(omitEmpty);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.YamlFile}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.YamlFile build() {
            return new io.github.cdklabs.projen.YamlFile(
                this.project,
                this.filePath,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/YamlFile.java <==
package io.github.cdklabs.projen;

/**
 * (experimental) Represents a YAML file.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.166Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.YamlFile")
public class YamlFile extends io.github.cdklabs.projen.ObjectFile {

    protected YamlFile(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected YamlFile(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param filePath This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public YamlFile(final @org.jetbrains.annotations.NotNull software.constructs.IConstruct scope, final @org.jetbrains.annotations.NotNull java.lang.String filePath, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.YamlFileOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(filePath, "filePath is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Implemented by derived classes and returns the contents of the file to emit.
     * <p>
     * @param resolver This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @Override
    protected @org.jetbrains.annotations.Nullable java.lang.String synthesizeContent(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.IResolver resolver) {
        return software.amazon.jsii.Kernel.call(this, "synthesizeContent", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { java.util.Objects.requireNonNull(resolver, "resolver is required") });
    }

    /**
     * (experimental) Maximum line width (set to 0 to disable folding).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.Number getLineWidth() {
        return software.amazon.jsii.Kernel.get(this, "lineWidth", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
    }

    /**
     * (experimental) Maximum line width (set to 0 to disable folding).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void setLineWidth(final @org.jetbrains.annotations.NotNull java.lang.Number value) {
        software.amazon.jsii.Kernel.set(this, "lineWidth", java.util.Objects.requireNonNull(value, "lineWidth is required"));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.YamlFile}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.YamlFile> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param filePath This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final software.constructs.IConstruct scope, final java.lang.String filePath) {
            return new Builder(scope, filePath);
        }

        private final software.constructs.IConstruct scope;
        private final java.lang.String filePath;
        private final io.github.cdklabs.projen.YamlFileOptions.Builder options;

        private Builder(final software.constructs.IConstruct scope, final java.lang.String filePath) {
            this.scope = scope;
            this.filePath = filePath;
            this.options = new io.github.cdklabs.projen.YamlFileOptions.Builder();
        }

        /**
         * (experimental) Indicates whether this file should be committed to git or ignored.
         * <p>
         * By
         * default, all generated files are committed and anti-tamper is used to
         * protect against manual modifications.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param committed Indicates whether this file should be committed to git or ignored. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder committed(final java.lang.Boolean committed) {
            this.options.committed(committed);
            return this;
        }

        /**
         * (experimental) Update the project's .gitignore file.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param editGitignore Update the project's .gitignore file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder editGitignore(final java.lang.Boolean editGitignore) {
            this.options.editGitignore(editGitignore);
            return this;
        }

        /**
         * (experimental) Whether the generated file should be marked as executable.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param executable Whether the generated file should be marked as executable. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder executable(final java.lang.Boolean executable) {
            this.options.executable(executable);
            return this;
        }

        /**
         * (experimental) Adds the projen marker to the file.
         * <p>
         * Default: - marker will be included as long as the project is not ejected
         * <p>
         * @return {@code this}
         * @param marker Adds the projen marker to the file. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder marker(final java.lang.Boolean marker) {
            this.options.marker(marker);
            return this;
        }

        /**
         * (experimental) Whether the generated file should be readonly.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param readonly Whether the generated file should be readonly. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder readonly(final java.lang.Boolean readonly) {
            this.options.readonly(readonly);
            return this;
        }

        /**
         * (experimental) The object that will be serialized. You can modify the object's contents before synthesis.
         * <p>
         * Serialization of the object is similar to JSON.stringify with few enhancements:
         * <p>
         * <ul>
         * <li>values that are functions will be called during synthesis and the result will be serialized - this allow to have lazy values.</li>
         * <li><code>Set</code> will be converted to array</li>
         * <li><code>Map</code> will be converted to a plain object ({ key: value, ... }})</li>
         * <li><code>RegExp</code> without flags will be converted to string representation of the source</li>
         * </ul>
         * <p>
         * Default: {} an empty object (use `file.obj` to mutate).
         * <p>
         * @return {@code this}
         * @param obj The object that will be serialized. You can modify the object's contents before synthesis. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder obj(final java.lang.Object obj) {
            this.options.obj(obj);
            return this;
        }

        /**
         * (experimental) Omits empty objects and arrays.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param omitEmpty Omits empty objects and arrays. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder omitEmpty(final java.lang.Boolean omitEmpty) {
            this.options.omitEmpty(omitEmpty);
            return this;
        }

        /**
         * (experimental) Maximum line width (set to 0 to disable folding).
         * <p>
         * Default: - 0
         * <p>
         * @return {@code this}
         * @param lineWidth Maximum line width (set to 0 to disable folding). This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lineWidth(final java.lang.Number lineWidth) {
            this.options.lineWidth(lineWidth);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.YamlFile}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.YamlFile build() {
            return new io.github.cdklabs.projen.YamlFile(
                this.scope,
                this.filePath,
                this.options.build()
            );
        }
    }
}
